Lidaco
########################################

Wind **Li**dar **Da**ta **Co**nverter.

Usage
=============

Install
-----
.. code-block:: bash
    pip install lidaco

Run
-----
.. code-block:: bash
    lidaco --config-file=samples/Windscanner/config.yaml


Extending
=============
.. code-block:: python
    # Create a new Reader or a Writer extending its correspondent base class

.. code-block:: python
    # Create one instance of that Reader and or Writer and pass it to the builder

Contributing
=============
    Clone the development

Send us feedback
=============


